@@ -5,7 +5,7 @@
 #include "mysql.h"
 #include "forms.h"
 
-#define XMYSQL_VERSION "1.9"
+#define XMYSQL_VERSION "1.10"
 #define MYSQL_VERSION  "3.22.8  Xforms 0.88"
 
 #define XMYSQL_WRAP_LENGTH        40  /* 20 seems good for me */
@@ -19,6 +19,9 @@
 #define SPECIAL_ADD_REC        1
 #define SPECIAL_UPDATE_REC     2
 
+#define USAGE_LINE \
+"\nUSAGE:\nxmysql [-host hst] [-user usr -password [pw]] [-port #] [-socket pth] [-qlimit #]\n"
+
 typedef struct _FieldInfo {
   MYSQL_FIELD field;
 } FieldInfo;
