@@ -1,5 +1,6 @@
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 #include "forms.h"
 #include "Xmysql.h"
 #include "XmysqlErr.h"
@@ -16,7 +17,8 @@ main (int argc, char *argv[])
 	int arg;
 	char *xpm_arg = getenv ("XMYSQL_XPMPATH");
 	char *hlp_arg = getenv ("XMYSQL_HELPPATH");
-
+	int ask_pass = 0;
+	
 	fl_initialize (&argc, argv, 0, 0, 0);
 
 	memset (CURRENT_DATABASE, 0, sizeof (CURRENT_DATABASE));
@@ -40,24 +42,58 @@ main (int argc, char *argv[])
 
 	for (arg = 1; arg < argc; arg++) {
 		if (!strcmp (argv[arg], "-host"))
-			strcpy (CURRENT_SERVER, argv[++arg]);
+			if (arg < argc - 1)
+				strcpy (CURRENT_SERVER, argv[++arg]);
+			else {
+				printf (USAGE_LINE);
+				return -1;
+			}
 		else if (!strcmp (argv[arg], "-user"))
-			strcpy (CURRENT_USER, argv[++arg]);
+			if (arg < argc - 1)
+				strcpy (CURRENT_USER, argv[++arg]);
+			else {
+				printf (USAGE_LINE);
+				return -1;
+			}
 		else if (!strcmp (argv[arg], "-password"))
-			strcpy (CURRENT_PASSWORD, argv[++arg]);
+			if ((arg < argc - 1) && (argv[arg+1][0] != '-')) {
+				strcpy(CURRENT_PASSWORD, argv[++arg]);
+			}
+			else
+				ask_pass = 1;
 		else if (!strcmp (argv[arg], "-qlimit"))
-			QUICK_LIMIT = atoi (argv[++arg]);
+			if (arg < argc - 1)
+				QUICK_LIMIT = atoi (argv[++arg]);
+			else {
+				printf (USAGE_LINE);
+				return -1;
+			}
 		else if (!strcmp (argv[arg], "-port"))
-			strcpy (CURRENT_PORT, argv[++arg]);
+			if (arg < argc - 1)
+				strcpy (CURRENT_PORT, argv[++arg]);
+			else {
+				printf (USAGE_LINE);
+				return -1;
+			}
 		else if (!strcmp (argv[arg], "-socket"))
-			strcpy (CURRENT_SOCKET, argv[++arg]);
+			if (arg < argc - 1)
+				strcpy (CURRENT_SOCKET, argv[++arg]);
+			else {
+				printf (USAGE_LINE);
+				return -1;
+			}
 		else if (!strcmp (argv[arg], "-help")) {
-			printf ("\nUSAGE:\n");
-			printf ("xmysql [-host hst] [-user usr -password pw] [-port #] [-socket pth] [-qlimit #]\n");
+			printf (USAGE_LINE);
 			return -1;
 		}
 	}
 
+  /* ask user for password if required */
+	if (ask_pass)
+		strncpy (CURRENT_PASSWORD, 
+						(char *) getpass ("Password: "), MAX_ARG_STRING	- 1);
+
+	/* create main screen */
 	fd_Xmysql_main = create_form_Xmysql_main ();
 
 	/* fill-in form initialization code */
